/*\
 * asteroid.h - the asteroid struct and related code
 * asteroid.exe: a version of Asteroids by Charles Lindsay
 * Copyright (C) 2003, 2005 Charles Lindsay
 *
 * Asteroids is originally copyright (C) 1979 Atari, Inc.
 *
 * This version of Asteroids is released under the GNU GPL and as
 * such, comes with absolutely no warranty of any kind, whatsoever.
 * See asteroid-license.txt for more information.
 *
 * webpage: http://chaoslizard.sourceforge.net/asteroid/
 * contact: chaoslizard@gamebox.net
 *
 * date        author   comments
 * ----        ------   --------
 * 2003-11-18  Charles  added regions (for clipping)
 * 2003-12-08  Charles  changed objects to linked lists for memory efficiency
 * 2003-12-09  Charles  moved from game_objs.h into its own file
 *
\*/


#ifndef __ASTEROID_H__
#define __ASTEROID_H__


//an asteroid object in the game
typedef struct _ASTEROID
{
   VECTOR2      pos;         //position
   VECTOR2      vel;         //velocity

   float        rot;         //current rotation
   float        rot_vel;     //rotation velocity
   VECTOR3      rot_axis;    //axis of rotation

   float        scale;       //scale (small, medium, or big)

   unsigned int region;      //which region it's in (for efficient clipping)
   CIRCLE       clip_circle; //clipping circle

} ASTEROID;


void FillAsteroidModel(void); //fills the asteroid model

void SpawnAsteroid(ASTEROID *, const VECTOR2 *, float); //resets the asteroid object
void UpdateAsteroid(ASTEROID *);                        //updates an asteroid
void DrawAsteroid(ASTEROID *);                          //draws an asteroid


#endif
