/*\
 * game.h - declarations needed for the game "engine"
 * asteroid.exe: a version of Asteroids by Charles Lindsay
 * Copyright (C) 2003, 2005 Charles Lindsay
 *
 * Asteroids is originally copyright (C) 1979 Atari, Inc.
 *
 * This version of Asteroids is released under the GNU GPL and as
 * such, comes with absolutely no warranty of any kind, whatsoever.
 * See asteroid-license.txt for more information.
 *
 * webpage: http://chaoslizard.sourceforge.net/asteroid/
 * contact: chaoslizard@gamebox.net
 *
 * date        author   comments
 * ----        ------   --------
 * 2003-10-01  Charles  initial implementation
 * 2003-10-02  Charles  added shots
 * 2003-11-05  Charles  various tweaks
 * 2003-12-04  Charles  added cheats
 * 2003-12-05  Charles  moved vector2 to model.h
 * 2003-12-08  Charles  removed statically allocated objects, now uses lists
 * 2003-12-09  Charles  added pause
 * 2003-12-12  Charles  added powerups
 * 2003-12-20  Charles  added InitGame and NewBurst
 * 2003-12-21  Charles  removed maximum starting asteroids
 * 2005-10-31  Scott    added sounds
 * 2005-11-03  Charles  moved Scott's code to sound.c/.h
 *
\*/


#ifndef __GAME_H__
#define __GAME_H__


#define DEG_TO_RAD 0.0174532925f //pi / 180


#define MAX_PLAYER_SHOTS       4 //max player shots


void TogglePause(void);//toggles between paused and unpaused

void InitGame(void);   //called once to set up game
void NewGame(void);    //called to start the game over
void NextLevel(void);  //clears the screen, goes to next level
void UpdateGame(void); //updates the world
void Render(void);     //renders one frame

unsigned int GetRegion(const VECTOR2 *, float); //gets a region code from a position

void NewShot(const VECTOR2 *, const VECTOR2 *, float, int); //adds a shot to the list of shots
void NewAlien(int);             //adds an alien to the list of aliens
void NewPowerup(void);          //adds a powerup
void NewBurst(const VECTOR2 *, const char *, ...); //spawns a text burst
void DestroyAllAsteroids(int);  //destroys all active asteroids

#define KEY_MASK_ACCEL 0x00000001 //masks for the different keys
#define KEY_MASK_SHOOT 0x00000002
#define KEY_MASK_LEFT  0x00000004
#define KEY_MASK_RIGHT 0x00000008
void ProcKey(int, int); //handles key-presses


#endif
