/*\
 * render.h - defines generic model structures et al.
 * asteroid.exe: a version of Asteroids by Charles Lindsay
 * Copyright (C) 2003, 2005 Charles Lindsay
 *
 * Asteroids is originally copyright (C) 1979 Atari, Inc.
 *
 * This version of Asteroids is released under the GNU GPL and as
 * such, comes with absolutely no warranty of any kind, whatsoever.
 * See asteroid-license.txt for more information.
 *
 * webpage: http://chaoslizard.sourceforge.net/asteroid/
 * contact: chaoslizard@gamebox.net
 *
 * date        author   comments
 * ----        ------   --------
 * 2003-09-11  Charles  initial implementation
 * 2003-09-30  Charles  added normals
 * 2003-11-20  Charles  added font-rendering
 * 2003-12-02  Charles  changed model struct and the way models are dealt with
 * 2003-12-05  Charles  removed static vertex definition structure, moved vector2 here,
 *                      and added x y and z names to vector3
 * 2003-12-07  Charles  added textures (don't belong here, but oh well) and colors to text
 * 2003-12-09  Charles  renamed render.h (from model.h)
 * 2003-12-21  Charles  made render accept z coordinate as well
 * 2005-03-09  Charles  removed SetTexture and added texture param to CreateModel
 *
\*/


#ifndef __RENDER_H__
#define __RENDER_H__


//a 2D vector
typedef struct _VECTOR2
{
   union
   {
      struct
      {
         float x, y; //x and y components
      };

      float v[2];
   };

} VECTOR2;

//a 3D vector
typedef struct _VECTOR3
{
   union
   {
      struct
      {
         float x, y, z;
      };

      float v[3];    //three floats that define the vector's position
   };

} VECTOR3;

//a model - now just an opengl list
typedef unsigned int MODEL;

//a texture--an opengl texture thingy
typedef unsigned int TEXTURE;


MODEL CreateModel(const VECTOR3 *, const unsigned int *, unsigned int,
                  const VECTOR3 *, int, const VECTOR3 *, const VECTOR2 *,
                  const TEXTURE *); //makes a model object
void DrawModel(MODEL); //draws a model object

TEXTURE CreateTexture(const char *); //loads a texture from a file
//void SetTexture(TEXTURE);            //uses the texture to draw models

int RenderText(float, float, float, float, float, float, float, const char *, ...); //outputs text

void WrapVector(VECTOR2 *); //wraps vectors around the screen


#endif
