/*\
 * shot.h - the shot struct and related code
 * asteroid.exe: a version of Asteroids by Charles Lindsay
 * Copyright (C) 2003, 2005 Charles Lindsay
 *
 * Asteroids is originally copyright (C) 1979 Atari, Inc.
 *
 * This version of Asteroids is released under the GNU GPL and as
 * such, comes with absolutely no warranty of any kind, whatsoever.
 * See asteroid-license.txt for more information.
 *
 * webpage: http://chaoslizard.sourceforge.net/asteroid/
 * contact: chaoslizard@gamebox.net
 *
 * date        author   comments
 * ----        ------   --------
 * 2003-11-18  Charles  added regions (for clipping)
 * 2003-12-08  Charles  changed objects to linked lists for memory efficiency
 * 2003-12-09  Charles  moved from game_objs.h into its own file
 *
\*/


#ifndef __SHOT_H__
#define __SHOT_H__


#define SHOT_LIFE 50 //how many frames the shot stays alive


//a bullet
typedef struct _SHOT
{
   VECTOR2      pos;          //position
   VECTOR2      vel;          //velocity

   unsigned int life;         //how many frames left until it disappears

   unsigned int region;       //which region it's in (for efficient clipping)

   int          player_owned; //1 if shot from player, 0 otherwise

} SHOT;


void SpawnShot(SHOT *, const VECTOR2 *, const VECTOR2 *, float, int); //makes a new shot
void UpdateShot(SHOT *);                                              //updates a shot
void DrawShot(SHOT *);                                                //draws the shot


#endif
